@@ -13,23 +13,21 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import grpc_helpers
-from google.api_core import operations_v1
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, grpc_helpers, operations_v1
 import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
-import grpc  # type: ignore
-
-from google.cloud.functions_v1.types import functions
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
 from google.longrunning import operations_pb2  # type: ignore
-from .base import CloudFunctionsServiceTransport, DEFAULT_CLIENT_INFO
+import grpc  # type: ignore
+
+from google.cloud.functions_v1.types import functions
+
+from .base import DEFAULT_CLIENT_INFO, CloudFunctionsServiceTransport
 
 
 class CloudFunctionsServiceGrpcTransport(CloudFunctionsServiceTransport):
@@ -63,6 +61,7 @@ class CloudFunctionsServiceGrpcTransport(CloudFunctionsServiceTransport):
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
     ) -> None:
         """Instantiate the transport.
 
@@ -159,6 +158,7 @@ class CloudFunctionsServiceGrpcTransport(CloudFunctionsServiceTransport):
             quota_project_id=quota_project_id,
             client_info=client_info,
             always_use_jwt_access=always_use_jwt_access,
+            api_audience=api_audience,
         )
 
         if not self._grpc_channel:
